@@ -48,9 +48,8 @@ extern "C" int getpagesize();   // argh, have to define prototype!
 
 #ifdef __linux__
 // -- global constants ---------------------------------------------------
-static const char *STAT_NAME = "stat";
-static const char *MEMINFO_NAME = "meminfo";
-static const char *MTAB_NAME = "/etc/mtab";
+#define STAT_NAME "/proc/stat"
+#define MEMINFO_NAME "/proc/meminfo"
 #endif
 
 // -- KSample::Sample definition -----------------------------------------
@@ -98,28 +97,21 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   memstats[6].name = 0;
   memstats[6].stat = 0;
 
-
-  parseMtab(proc);
-
-  char file[512];
-  snprintf(file, sizeof(file), "%s/%s", proc, MEMINFO_NAME);
-
-  if ((memFD = open(file, O_RDONLY)) == -1) {
+  if ((memFD = open(MEMINFO_NAME, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
                        i18n("Unable to open the file '%1'. The diagnostics are:\n%2.\n"
                             "This file is required to determine current memory usage.\n"
-                            "Maybe your proc filesystem is non-Linux standard?").arg(file).arg(strerror(errno)));
+                            "Maybe your proc filesystem is non-Linux standard?").arg(MEMINFO_NAME).arg(strerror(errno)));
     exit(1);
   }
 
   fcntl( memFD,F_SETFD, FD_CLOEXEC );
 
-  snprintf(file, sizeof(file), "%s/%s", proc, STAT_NAME);
-  if ((statFD = open(file, O_RDONLY)) == -1) {
+  if ((statFD = open(STAT_NAME, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
                        i18n("Unable to open the file '%1'. The diagnostics are:\n%2.\n"
                             "This file is required to determine current system info. "
-                            "Maybe your proc filesystem is non-Linux standard?").arg(file).arg(strerror(errno)));
+                            "Maybe your proc filesystem is non-Linux standard?").arg(MEMINFO_NAME).arg(strerror(errno)));
     exit(1);
   }
 
@@ -157,70 +149,6 @@ KSample::~KSample()
 #endif
 }
 
-#ifdef __linux__
-// Parse /etc/mtab to determine the proc filesystem mount point.
-void KSample::parseMtab(char *dest)
-{
-    std::ifstream *mtab = new std::ifstream(MTAB_NAME);
-    if (!mtab->good()) {
-        KMessageBox::error(timemon, i18n("Unable to open file '%1' to determine where the proc "
-                                         "filesystem is mounted. The diagnostics are:\n%2\n"
-                                         "Are you really running UNIX?").arg( MTAB_NAME).arg( strerror(errno)));
-        delete mtab;
-        exit(1);
-    }
-
-    unsigned lineno = 0;
-    char line[1024];
-    QString errormsg;
-
-    for (;;) {
-        lineno++;
-        mtab->getline(line, sizeof(line));
-
-        if (mtab->bad()) {
-            errormsg = i18n("Unable to read file '%1' to determine where the proc "
-                            "filesystem is mounted. The diagnostics are:\n %2").arg(MTAB_NAME).arg(strerror(errno));
-            break;
-        }
-
-        if (mtab->eof()) {
-            errormsg = i18n("Unable to determine where the proc filesystem "
-                            "is mounted (there is no entry in '%1').\n"
-                            "Information is required from the proc filesystem to "
-                            "determine current system usage. Maybe you are not running "
-			    "Linux (Unfortunately the proc filesystem is Linux specific)?\n"
-                            "If you can provide help with porting KTimeMon to your "
-                            "platform, please contact the maintainer at mueller@kde.org").arg(MTAB_NAME);
-            break;
-        }
-
-	if (mtab->fail()) {
-            errormsg = i18n("A very long line was encountered while reading "
-                            "information in '%1' (where \"very long\" is defined "
-                            "as > %2). This happened at line %3.\n"
-                            "Is %4 the mount table on your platform?")
-                .arg(MTAB_NAME).arg(sizeof(line)).arg(lineno).arg(MTAB_NAME);
-            break;
-        }
-
-        char *p, *m;
-
-        if ((p = m = strchr(line, ' ')) != 0) p = strchr(m+1, ' ');
-        if (p == 0 || strncmp(p+1, "proc ", 5) != 0) continue;
-
-        *p = '\0';
-        strncpy(dest, m+1, 256);
-        mtab->close();
-        delete mtab;
-        return;
-    }
-
-    KMessageBox::error(timemon, errormsg);
-    exit(1);
-}
-#endif
-
 // Set the appropriate scaling parameters
 void KSample::setScaling(bool a, unsigned p, unsigned s, unsigned c)
 {
@@ -280,8 +208,8 @@ void KSample::readSample()
     lseek(memFD, 0, 0);
     if ((l = read(memFD, buffer, sizeof(buffer) - 1)) < 0)
     {
-        fatal(i18n("Unable to read the memory usage file '%1/%2'.\n"
-                   "The diagnostics are: %3").arg(proc).arg(MEMINFO_NAME).arg(strerror(errno)));
+        fatal(i18n("Unable to read the memory usage file '%1'.\n"
+                   "The diagnostics are: %2").arg(MEMINFO_NAME).arg(strerror(errno)));
     }
     buffer[l] = '\0';
     l = 0;
@@ -290,11 +218,11 @@ void KSample::readSample()
         p = strstr(buffer, memstats[l].name);
         if (p == 0 ||
             sscanf(p + strlen(memstats[l].name), "%lu kB", memstats[l].stat) < 1)
-            fatal(i18n("The memory usage file '%1/%2' seems to use a "
+            fatal(i18n("The memory usage file '%1' seems to use a "
                        "different file format than expected.\n"
                        "Maybe your version of the proc filesystem is "
                        "incompatible with supported versions. "
-		       "Please contact the developer at m.maierhofer@tees.ac.uk who will try to sort this out.").arg(proc).arg(MEMINFO_NAME));
+		       "Please contact the developer at http://bugs.kde.org/ who will try to sort this out.").arg(MEMINFO_NAME));
         l++;
     }
 
@@ -306,8 +234,8 @@ void KSample::readSample()
 
     lseek(statFD, 0, 0);
     if ((l = read(statFD, buffer, sizeof(buffer)-1)) < 0)
-        fatal(i18n("Unable to read the system usage file '%1/%2'.\n"
-                   "The diagnostics are: %3").arg(proc).arg(STAT_NAME).arg(strerror(errno)));
+        fatal(i18n("Unable to read the system usage file '%1'.\n"
+                   "The diagnostics are: %2").arg(STAT_NAME).arg(strerror(errno)));
 
     buffer[l] = '\0';
 
@@ -488,6 +416,7 @@ void KSample::readSample()
 
 #else
 #warning This type of system is not supported
+    sample.stotal = sample.sfree = 0;
 #endif
 
     sample.cputotal = sample.user + sample.nice + sample.kernel + sample.idle;
