@@ -84,7 +84,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
     QString ext;
     KActionMenu * actionMenu;
     KAction * action;
-    if ( hasOther )
+    if ( hasOther &&  m_list.first()->name()!="." && popupmenu->protocolInfo().supportsWriting() )	// don't try to compress if we right click on a folder without files selected
     {
         compMimeTypes();
         actionMenu = new KActionMenu( i18n( "Compress" ), "ark", actionCollection(), "ark_compress_menu"  );
@@ -126,29 +126,37 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
 
     if ( !hasOther && hasArchives )
     {
-        actionMenu = new KActionMenu( i18n( "Extract" ), "ark", actionCollection(), "ark_extract_menu"  );
-
-        action = new KAction( i18n( "Extract Here" ), 0, this,
-                                SLOT( slotExtractHere() ), actionCollection() );
-        actionMenu->insert( action );
-        // stolen from arkwidget.cpp
-        if ( itemCount == 1 )
+        if ( popupmenu->protocolInfo().supportsWriting() )
         {
-            QString targetName = m_list.first()->name();
-            stripExtension( targetName );
-            action = new KAction( i18n( "Extract to %1" ).arg( targetName ), 0, this,
-                                    SLOT( slotExtractToSubfolders() ), actionCollection() );
+            actionMenu = new KActionMenu( i18n( "Extract" ), "ark", actionCollection(), "ark_extract_menu"  );
+
+            action = new KAction( i18n( "Extract Here" ), 0, this,
+                                    SLOT( slotExtractHere() ), actionCollection() );
+            actionMenu->insert( action );
+            // stolen from arkwidget.cpp
+            if ( itemCount == 1 )
+            {
+                QString targetName = m_list.first()->name();
+                stripExtension( targetName );
+                action = new KAction( i18n( "Extract to %1" ).arg( targetName ), 0, this,
+                                        SLOT( slotExtractToSubfolders() ), actionCollection() );
+            }
+            else
+            {
+                action = new KAction( i18n( "Extract to Subfolders" ), 0, this,
+                                        SLOT( slotExtractToSubfolders() ), actionCollection() );
+            }
+            actionMenu->insert( action );
+            action = new KAction( i18n( "Extract To..." ), 0 , this,
+                                    SLOT( slotExtractTo() ), actionCollection() );
+            actionMenu->insert( action );
+            addAction( actionMenu );
         }
         else
         {
-            action = new KAction( i18n( "Extract to Subfolders" ), 0, this,
-                                    SLOT( slotExtractToSubfolders() ), actionCollection() );
+           action = new KAction( i18n( "Extract To..." ), "ark", 0,  this, SLOT( slotExtractTo() ), actionCollection(), "ark_extract_menu" );
+           addAction( action );
         }
-        actionMenu->insert( action );
-        action = new KAction( i18n( "Extract To..." ), 0 , this,
-                                SLOT( slotExtractTo() ), actionCollection() );
-        actionMenu->insert( action );
-        addAction( actionMenu );
     }
     addSeparator();
 }
@@ -246,18 +254,22 @@ void ArkMenu::slotPrepareAddToMenu()
 
 void ArkMenu::compMimeTypes()
 {
+    unsigned int itemCount = m_list.count();
+
     bool havegz = false;
     if ( !KStandardDirs::findExe( "gzip" ).isNull() && m_conf->readBoolEntry( "UseGz", true ) )
     {
         havegz = true;
-        m_archiveMimeTypes << "application/x-gzip";
+        //.gz can only compress one file, not multiple 
+        if ( itemCount == 1 ) m_archiveMimeTypes << "application/x-gzip";
     }
 
     bool havebz2 = false;
     if ( !KStandardDirs::findExe( "bzip2" ).isNull() && m_conf->readBoolEntry( "UseBzip2", true ) )
     {
         havebz2 = true;
-        m_archiveMimeTypes << "application/x-bzip2";
+        //.bz2 can only compress one file, not multiple
+        if ( itemCount == 1 ) m_archiveMimeTypes << "application/x-bzip2";
     }
 
     bool havelzop = false;
@@ -397,6 +409,13 @@ void ArkMenu::slotCompressAs( int pos )
          ++it;
          filelist.append( item->url().url() );
     }
+    //if KMimeType returns .ZIP or .RAR. convert them to lowercase
+    if ( m_extensionList[ pos ].contains ( ".ZIP" ) )
+         m_extensionList[ pos ] = ".zip";
+
+    if ( m_extensionList[ pos ].contains ( ".RAR" ) )
+         m_extensionList[ pos ] = ".rar";
+
     if ( filelist.count() == 1)
          target = filelist.first() + m_extensionList[ pos ];
     else
