@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __kdirmenu_h
@@ -26,11 +26,12 @@
 #include <qmap.h>
 
 class KAction;
+class KURL;
 
 class KDirMenu : public QPopupMenu {
     Q_OBJECT
 public:
-    KDirMenu( QWidget *parent, const QString &src, const QString &_path, 
+    KDirMenu( QWidget *parent, const KURL &src, const QString &_path,
             const QString &name, bool showfiles = false  );
     ~KDirMenu( );
     void setPath( const QString &_path);
@@ -44,7 +45,7 @@ signals:
 private:
     QString path;
     QString name;
-    QString src;
+    KURL src;
     KAction *action;
     QPtrList<KDirMenu> children;
     void initIconMap( );
