@@ -2,6 +2,7 @@
  *   Copyright (C) 2002, Anders Lund <anders@alweb.dk>                     *
  *   Copyright (C) 2003, 2004, Franck Qulain <shift@free.fr>              *
  *   Copyright (C) 2004, Kevin Krammer <kevin.krammer@gmx.at>              *
+ *   Copyright (C) 2004, 2005, Oliviet Goffart <ogoffart @ kde.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +17,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 
@@ -109,6 +110,13 @@ private slots:
 
 private:
 
+    /**
+     * Try to guess some relations from the url, if the document doesn't contains relations
+	 * example:   http://example.com/page4.html
+	 * the "next" relation will be set to page5.html
+	 */
+	void guessRelations();
+	
     /**
      * Function used to get link type of a relation.
      * For example "prev" is of type "previous" and "toc" is of type "contents"
