@@ -13,9 +13,12 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#ifndef FILE_H
+#define FILE_H
+
 #include <stdio.h>
 #include "renderer.h"
 #include <stdlib.h>
@@ -23,3 +26,6 @@
 extern void save_effect(t_effect *_effect);
 extern void load_effects(void);
 void load_random_effect(t_effect *effect);
+
+#endif // FILE_H
+
